==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/RecoveryPlanScriptActionDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.RecoveryPlanScriptActionDetailsArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.RecoveryPlanActionLocation
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Recovery plan script action details.
 * @property fabricLocation The fabric location.
 * @property instanceType Gets the type of action details (see RecoveryPlanActionDetailsTypes enum for possible values).
 * Expected value is 'ScriptActionDetails'.
 * @property path The script path.
 * @property timeout The script timeout.
 */
public data class RecoveryPlanScriptActionDetailsArgs(
    public val fabricLocation: Output<Either<String, RecoveryPlanActionLocation>>,
    public val instanceType: Output<String>,
    public val path: Output<String>,
    public val timeout: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.RecoveryPlanScriptActionDetailsArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.RecoveryPlanScriptActionDetailsArgs =
        com.pulumi.azurenative.recoveryservices.inputs.RecoveryPlanScriptActionDetailsArgs.builder()
            .fabricLocation(
                fabricLocation.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .instanceType(instanceType.applyValue({ args0 -> args0 }))
            .path(path.applyValue({ args0 -> args0 }))
            .timeout(timeout?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RecoveryPlanScriptActionDetailsArgs].
 */
@PulumiTagMarker
public class RecoveryPlanScriptActionDetailsArgsBuilder internal constructor() {
    private var fabricLocation: Output<Either<String, RecoveryPlanActionLocation>>? = null

    private var instanceType: Output<String>? = null

    private var path: Output<String>? = null

    private var timeout: Output<String>? = null

    /**
     * @param value The fabric location.
     */
    @JvmName("kyaxfodprxaqhnwf")
    public suspend fun fabricLocation(`value`: Output<Either<String, RecoveryPlanActionLocation>>) {
        this.fabricLocation = value
    }

    /**
     * @param value Gets the type of action details (see RecoveryPlanActionDetailsTypes enum for possible values).
     * Expected value is 'ScriptActionDetails'.
     */
    @JvmName("uvuadqaapvxjmmcn")
    public suspend fun instanceType(`value`: Output<String>) {
        this.instanceType = value
    }

    /**
     * @param value The script path.
     */
    @JvmName("vvnsjexpilvpicqm")
    public suspend fun path(`value`: Output<String>) {
        this.path = value
    }

    /**
     * @param value The script timeout.
     */
    @JvmName("wihwltuhetwjryrw")
    public suspend fun timeout(`value`: Output<String>) {
        this.timeout = value
    }

    /**
     * @param value The fabric location.
     */
    @JvmName("kkoaeebaecgdwscn")
    public suspend fun fabricLocation(`value`: Either<String, RecoveryPlanActionLocation>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.fabricLocation = mapped
    }

    /**
     * @param value The fabric location.
     */
    @JvmName("oaqywktnbfouwhel")
    public fun fabricLocation(`value`: String) {
        val toBeMapped = Either.ofLeft<String, RecoveryPlanActionLocation>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.fabricLocation = mapped
    }

    /**
     * @param value The fabric location.
     */
    @JvmName("irewduhyndgrcwyw")
    public fun fabricLocation(`value`: RecoveryPlanActionLocation) {
        val toBeMapped = Either.ofRight<String, RecoveryPlanActionLocation>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.fabricLocation = mapped
    }

    /**
     * @param value Gets the type of action details (see RecoveryPlanActionDetailsTypes enum for possible values).
     * Expected value is 'ScriptActionDetails'.
     */
    @JvmName("mkppsssjjwoobfhl")
    public suspend fun instanceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.instanceType = mapped
    }

    /**
     * @param value The script path.
     */
    @JvmName("pjcnphhlppcvgnqu")
    public suspend fun path(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.path = mapped
    }

    /**
     * @param value The script timeout.
     */
    @JvmName("ecpfjpvpblgkhxin")
    public suspend fun timeout(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timeout = mapped
    }

    internal fun build(): RecoveryPlanScriptActionDetailsArgs = RecoveryPlanScriptActionDetailsArgs(
        fabricLocation = fabricLocation ?: throw PulumiNullFieldException("fabricLocation"),
        instanceType = instanceType ?: throw PulumiNullFieldException("instanceType"),
        path = path ?: throw PulumiNullFieldException("path"),
        timeout = timeout,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/RecoveryPlanScriptActionDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.RecoveryPlanScriptActionDetailsArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.RecoveryPlanActionLocation
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Recovery plan script action details.
 * @property fabricLocation The fabric location.
 * @property instanceType Gets the type of action details (see RecoveryPlanActionDetailsTypes enum for possible values).
 * Expected value is 'ScriptActionDetails'.
 * @property path The script path.
 * @property timeout The script timeout.
 */
public data class RecoveryPlanScriptActionDetailsArgs(
    public val fabricLocation: Output<Either<String, RecoveryPlanActionLocation>>,
    public val instanceType: Output<String>,
    public val path: Output<String>,
    public val timeout: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.RecoveryPlanScriptActionDetailsArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.RecoveryPlanScriptActionDetailsArgs =
        com.pulumi.azurenative.recoveryservices.inputs.RecoveryPlanScriptActionDetailsArgs.builder()
            .fabricLocation(
                fabricLocation.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .instanceType(instanceType.applyValue({ args0 -> args0 }))
            .path(path.applyValue({ args0 -> args0 }))
            .timeout(timeout?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RecoveryPlanScriptActionDetailsArgs].
 */
@PulumiTagMarker
public class RecoveryPlanScriptActionDetailsArgsBuilder internal constructor() {
    private var fabricLocation: Output<Either<String, RecoveryPlanActionLocation>>? = null

    private var instanceType: Output<String>? = null

    private var path: Output<String>? = null

    private var timeout: Output<String>? = null

    /**
     * @param value The fabric location.
     */
    @JvmName("dtljjgdsduupvtld")
    public suspend fun fabricLocation(`value`: Output<Either<String, RecoveryPlanActionLocation>>) {
        this.fabricLocation = value
    }

    /**
     * @param value Gets the type of action details (see RecoveryPlanActionDetailsTypes enum for possible values).
     * Expected value is 'ScriptActionDetails'.
     */
    @JvmName("wmdhohdlxtmjmnnu")
    public suspend fun instanceType(`value`: Output<String>) {
        this.instanceType = value
    }

    /**
     * @param value The script path.
     */
    @JvmName("vmehcurphppomhfn")
    public suspend fun path(`value`: Output<String>) {
        this.path = value
    }

    /**
     * @param value The script timeout.
     */
    @JvmName("eqsrsearlmghpvwh")
    public suspend fun timeout(`value`: Output<String>) {
        this.timeout = value
    }

    /**
     * @param value The fabric location.
     */
    @JvmName("rlfnyqaxexdkbjle")
    public suspend fun fabricLocation(`value`: Either<String, RecoveryPlanActionLocation>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.fabricLocation = mapped
    }

    /**
     * @param value The fabric location.
     */
    @JvmName("mtgnuiwlwqfplchf")
    public fun fabricLocation(`value`: String) {
        val toBeMapped = Either.ofLeft<String, RecoveryPlanActionLocation>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.fabricLocation = mapped
    }

    /**
     * @param value The fabric location.
     */
    @JvmName("yyrshwjoacwvyoth")
    public fun fabricLocation(`value`: RecoveryPlanActionLocation) {
        val toBeMapped = Either.ofRight<String, RecoveryPlanActionLocation>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.fabricLocation = mapped
    }

    /**
     * @param value Gets the type of action details (see RecoveryPlanActionDetailsTypes enum for possible values).
     * Expected value is 'ScriptActionDetails'.
     */
    @JvmName("bfjagxwvyhsrfpyg")
    public suspend fun instanceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.instanceType = mapped
    }

    /**
     * @param value The script path.
     */
    @JvmName("vpxdhsquxlgelbdm")
    public suspend fun path(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.path = mapped
    }

    /**
     * @param value The script timeout.
     */
    @JvmName("xiauioqshiqhqoir")
    public suspend fun timeout(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timeout = mapped
    }

    internal fun build(): RecoveryPlanScriptActionDetailsArgs = RecoveryPlanScriptActionDetailsArgs(
        fabricLocation = fabricLocation ?: throw PulumiNullFieldException("fabricLocation"),
        instanceType = instanceType ?: throw PulumiNullFieldException("instanceType"),
        path = path ?: throw PulumiNullFieldException("path"),
        timeout = timeout,
    )
}
